<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.8.6"/>
<title>IMP Manual: Search</title>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="search/search.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="search/search.js"></script>
<script type="text/javascript">
  $(document).ready(function() {
    if ($('.searchresults').length > 0) { searchBox.DOMSearchField().focus(); }
  });
</script>
<link rel="search" href="search-opensearch.php?v=opensearch.xml" type="application/opensearchdescription+xml" title="IMP Manual"/>
<script type="text/x-mathjax-config">
  MathJax.Hub.Config({
    extensions: ["tex2jax.js"],
    jax: ["input/TeX","output/HTML-CSS"],
});
</script><script src="//integrativemodeling.org/mathjax/MathJax.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
<link href="salilab-doxygen.css" rel="stylesheet" type="text/css"/>
<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.6.3/css/all.css" integrity="sha384-UHRtZLI+pbxtHCWp1t77Bi1L4ZtiqrqD80Kn4Z8NTSRyMA2Fd33n5dQ8lWUE00s/" crossorigin="anonymous" />
<link href="//integrativemodeling.org/imp.css" rel="stylesheet" type="text/css"/>
</head>
<body>
<div id="impnav">
   <table class="imptnav">
      <tr>
         <td><a href="//integrativemodeling.org/">
             <img src="//integrativemodeling.org/images/the_imp.png" height="60" alt="IMP logo" border="0"/></a></td>
         <td>
            <div id="implinks">
             <ul>
               <li><a href="//integrativemodeling.org/">home</a></li>
               <li><a href="//integrativemodeling.org/about.html">about</a></li>
               <li><a href="//integrativemodeling.org/news.html">news</a></li>
               <li><a href="//integrativemodeling.org/download.html">download</a></li>
               <li><a href="//integrativemodeling.org/doc.html">doc</a></li>
               <li><a href="https://github.com/salilab/imp">source</a></li>
               <li><a href="//integrativemodeling.org/systems/">systems</a></li>
               <li><a href="//integrativemodeling.org/nightly/results/">tests</a></li>
               <li><a href="https://github.com/salilab/imp/issues">bugs</a></li>
               <li><a href="//integrativemodeling.org/contact.html">contact</a></li>
           </ul>
            </div>
         </td>
      </tr>
   </table>
</div>
<div id="impheaderline">
</div>
  <div id="container">
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
 <tbody>
 <tr style="height: 56px;">
  <td style="padding-left: 0.5em;">
   <div id="projectname">IMP Manual
   &#160;<span id="projectnumber">for IMP version 2.14.0</span>
   </div>
  </td>
 </tr>
 </tbody>
</table>
</div>
<!-- end header part -->
<!-- Generated by Doxygen 1.8.6 -->
<script type="text/javascript">
var searchBox = new SearchBox("searchBox", "search",false,'Search');
</script>
  <div id="navrow1" class="tabs">
    <ul class="tablist">
      <li><a href="index.html"><span>IMP&#160;Manual</span></a></li>
      <li><a href="../ref/"><span>Reference&#160;Guide</span></a></li>
      <li><a href="https://integrativemodeling.org/tutorials/"><span>Tutorial&#160;Index</span></a></li>
      <li><a href="https://integrativemodeling.org/doc.html"><span>Other&#160;Versions</span></a></li>
      <li>
        <div id="MSearchBox" class="MSearchBoxInactive">
          <div class="left">
            <form id="FSearchBox" action="search.php" method="get">
              <img id="MSearchSelect" src="search/mag.png" alt=""/>
<?php
require_once "search-functions.php";
main();
?>
<!-- start footer part -->
<hr class="footer"/><address class="footer"><small>
<script type='text/javascript'>
  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
  ga('create', 'UA-44570008-3', 'salilab.org');
  ga('send', 'pageview');
</script>
</body>
</html>
